#! /usr/local/bin/python
#
import math
import os
import time
# Grid boundaries
#
tmin = 5.0  # minimum kinetic temperature (K)
tmax = 300.0 # maximum kinetic temperature (K)
nmin = 1e2   # minimum H2 density (cm^-3)
nmax = 1e7   # maximum H2 density (cm^-3)
#
# Parameters to keep constant
#
tbg   = 2.73 # background radiation temperature
flow  = 100
fupp  = 1500
dv    = 1.0  # line width (km/s)
#
# Numerical parameters
#
ntemp = 40  # number of temperature points
ndens = 40  # number of density points
mole = 'c18o'
cdmols = ('1e15','2e15','5e15','1e16','2e16','5e16')
#
# No user changes needed below this point.  Probably. :)
#
def write_input(infile,tkin,nh2,cdmol):
    infile.write(mole+'.dat\n')
    infile.write('escape.out\n')
    infile.write(str(flow)+' '+str(fupp)+'\n')
    infile.write(str(tkin)+'\n')
    infile.write('1\n')
    infile.write('H2\n')
    infile.write(str(nh2)+'\n')
    infile.write(str(tbg)+'\n')
    infile.write(str(cdmol)+'\n')
    infile.write(str(dv)+'\n')

def read_escape(outfile):
    jupp = []
    tb = []
    line  = outfile.readline()
    words = line.split()
    while (words[1] != "T(kin)"):
        line  = outfile.readline()
        words = line.split()
    temp  = float(words[-1])
    line  = outfile.readline()
    words = line.split()
    dens  = float(words[-1])
    while (words[-1] != "FLUX"):
        line  = outfile.readline()
        words = line.split()
    line  = outfile.readline()
    line  = outfile.readline()
    words = line.split()
    ftmp  = float(words[4])
    while ((ftmp < fupp) and (ftmp > flow)):
        jupp.append(words[0])
        tb.append(words[-2])
        line  = outfile.readline()
        words = line.split()
        if(words):
            if(words[0] == '*'):
                ftmp = 0
            else:
                ftmp  = float(words[4])
        else:
            ftmp = 0
    return temp,dens,jupp,tb
 
# Begin of main program

start = time.time()

for cdmol in cdmols:
    print "Starting N = ",cdmol, " for ", mole
    infile = open('escape.inp','w')
    for itemp in range(ntemp+1):
        for idens in range(ndens+1):

            temp = tmin*((tmax/tmin)**(float(itemp)/ntemp))
            dens = nmin*((nmax/nmin)**(float(idens)/ndens))
            write_input(infile,temp,dens,float(cdmol))
            if (itemp == ntemp and idens == ndens):
                infile.write('0\n')
                infile.close()
            else:
                infile.write('1\n')

    os.system('./escape-freebsd < escape.inp > /dev/null')

    fmt  = '%10.3e %10.3e %10.3e \n'
    outfile  = open('escape.out')

    for itemp in range(ntemp+1):
        for idens in range(ndens+1):
            temp = tmin*((tmax/tmin)**(float(itemp)/ntemp))
            dens = nmin*((nmax/nmin)**(float(idens)/ndens))
            temp,dens,jupp,tb = read_escape(outfile)
            for index,item in enumerate(jupp):
                gfil='grids/'+mole+item+'-'+`int(item)-1`+'_'+cdmol+'.dat'
                grid=open(gfil,'a')
                grid.write(fmt %(temp, math.log10(dens), float(tb[index])))
                grid.close()
    outfile.close()

stop = time.time()
dure = stop - start
print "Run time = ",dure, "seconds"
